@@ -1,7 +1,6 @@
 use crate::data::error::DataError;
 use crate::data::handler::{Continuation, Continuer, MarketGenerator};
 use crate::data::market::MarketEvent;
-use barter_data::client::ClientName as ExchangeName;
 use barter_data::model::{Candle, MarketData};
 use barter_data::ExchangeClient;
 use chrono::Utc;
@@ -14,7 +13,6 @@ use uuid::Uuid;
 /// Configuration for constructing a [LiveCandleHandler] via the new() constructor method.
 #[derive(Debug, Deserialize)]
 pub struct Config {
-    pub exchange: ExchangeName,
     pub symbol: String,
     pub interval: String,
 }
@@ -23,7 +21,7 @@ pub struct Config {
 /// [Continuer] & [MarketGenerator].
 #[derive(Debug)]
 pub struct LiveCandleHandler {
-    pub exchange: ExchangeName,
+    pub exchange: &'static str,
     pub symbol: String,
     pub interval: String,
     candle_rx: Receiver<Candle>,
@@ -51,7 +49,7 @@ impl MarketGenerator for LiveCandleHandler {
             event_type: MarketEvent::EVENT_TYPE,
             trace_id: Uuid::new_v4(),
             timestamp: Utc::now(),
-            exchange: format!("{:?}", self.exchange.clone()),
+            exchange: self.exchange,
             symbol: self.symbol.clone(),
             data: MarketData::Candle(candle),
         })
@@ -62,7 +60,7 @@ impl LiveCandleHandler {
     /// Constructs a new [LiveCandleHandler] component using the provided [Config]. The injected
     /// [ExchangeClient] is used to subscribe to a [Candle] stream. An asynchronous task is spawned
     /// to consume [Candle]s and route them to the [LiveCandleHandler]'s sync::mpsc::Receiver.
-    pub async fn init<Client: ExchangeClient>(cfg: &Config, mut exchange_client: Client) -> Self {
+    pub async fn init<Client: ExchangeClient>(cfg: Config, mut exchange_client: Client) -> Self {
         // Subscribe to Candle stream via exchange Client
         let mut candle_stream = exchange_client
             .consume_candles(cfg.symbol.clone(), &cfg.interval)
@@ -84,9 +82,9 @@ impl LiveCandleHandler {
         });
 
         Self {
-            exchange: cfg.exchange.clone(),
-            symbol: cfg.symbol.clone(),
-            interval: cfg.interval.clone(),
+            exchange: Client::EXCHANGE_NAME,
+            symbol: cfg.symbol,
+            interval: cfg.interval,
             candle_rx,
             can_continue: Continuation::Continue,
         }
@@ -101,7 +99,7 @@ impl LiveCandleHandler {
 /// Builder to construct [LiveCandleHandler] instances.
 #[derive(Debug, Default)]
 pub struct LiveCandleHandlerBuilder {
-    pub exchange: Option<ExchangeName>,
+    pub exchange: Option<&'static str>,
     pub symbol: Option<String>,
     pub interval: Option<String>,
     pub candle_rx: Option<Receiver<Candle>>,
@@ -112,7 +110,7 @@ impl LiveCandleHandlerBuilder {
         Self::default()
     }
 
-    pub fn exchange(self, value: ExchangeName) -> Self {
+    pub fn exchange(self, value: &'static str) -> Self {
         Self {
             exchange: Some(value),
             ..self
